==> mybb-1.4.4.tbz: www/mybb/inc/languages/english/newreply.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 * 
 * $Id: newreply.lang.php 4277 2008-11-23 20:47:16Z Tikitiki $
 */

$l['nav_newreply'] = "Post Reply";

$l['post_reply_to'] = "Post Reply to {1}";
$l['post_new_reply'] = "Post a New Reply";
$l['reply_to'] = "Reply to thread: {1}";
$l['post_subject'] = "Post Subject:";
$l['your_message'] = "Your Message:";
$l['post_options'] = "Post Options:";
$l['options_sig'] = "<strong>Signature:</strong> include your signature. (registered users only)";
$l['options_emailnotify'] = "<strong>Email Notification:</strong> receive an email whenever there is a new reply. (registered users only)";
$l['options_disablesmilies'] = "<strong>Disable Smilies:</strong> disable smilies from showing in this post.";
$l['post_reply'] = "Post Reply";
$l['preview_post'] = "Preview Post";
$l['mod_options'] ="Moderator Options:";
$l['close_thread'] = "<strong>Close Thread</strong>: prevent further posting in this thread.";
$l['stick_thread'] = "<strong>Stick Thread:</strong> stick this thread to the top of the forum.";
$l['thread_review'] = "Thread Review (Newest First)";
$l['thread_review_more'] = "This thread has more than {1} replies. <a href=\"{2}\">Read the whole thread.</a>";
$l['posted_by'] = "Posted by";
$l['draft_saved'] = "The new post has successfully been saved as a draft.<br />You will now be taken to your draft listing.";
$l['image_verification'] = "Image Verification";
$l['verification_note'] = "Please enter the text within the image on the left in to the text box below. This process is used to prevent automated posts.";
$l['verification_subnote'] = "(case insensitive)";
$l['invalid_captcha'] = "The image verification code that you entered was incorrect. Please enter the code exactly how it appears in the image.";
$l['error_post_already_submitted'] = "You have already posted this reply to the specified thread. Please visit the thread to see your reply.";
$l['multiquote_external_one'] = "You have selected one post outside of this thread.";
$l['multiquote_external'] = "You have selected {1} posts outside of this thread.";
$l['multiquote_external_one_deselect'] = "deselect this post";
$l['multiquote_external_deselect'] = "deselect these posts";
$l['multiquote_external_one_quote'] = "Quote this post too";
$l['multiquote_external_quote'] = "Quote these posts too";

$l['redirect_newreply'] = "Thank you, your reply has been posted.";
$l['redirect_newreply_moderation'] = "The administrator has specified that all new posts require moderation. You will now be returned to the thread.";
$l['redirect_newreply_post'] = "<br />You will now be taken to your post.";
$l['redirect_newreplyerror'] = "Sorry, but your reply has been rejected for lack of content. <br />You will now be returned to the thread.";
$l['redirect_threadclosed'] = "You cannot post replies in this thread because it has been closed by a moderator.";
?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/newreply.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 * 
 * $Id: newreply.lang.php 5617 2011-09-20 13:50:05Z Tomm $
 */

$l['nav_newreply'] = "Post Reply";

$l['post_reply_to'] = "Post Reply to {1}";
$l['post_new_reply'] = "Post a New Reply";
$l['reply_to'] = "Reply to thread: {1}";
$l['post_subject'] = "Post Subject:";
$l['your_message'] = "Your Message:";
$l['post_options'] = "Post Options:";
$l['options_sig'] = "<strong>Signature:</strong> include your signature. (registered users only)";
$l['options_emailnotify'] = "<strong>Email Notification:</strong> receive an email whenever there is a new reply. (registered users only)";
$l['options_disablesmilies'] = "<strong>Disable Smilies:</strong> disable smilies from showing in this post.";
$l['post_reply'] = "Post Reply";
$l['preview_post'] = "Preview Post";
$l['mod_options'] ="Moderator Options:";
$l['close_thread'] = "<strong>Close Thread</strong>: prevent further posting in this thread.";
$l['stick_thread'] = "<strong>Stick Thread:</strong> stick this thread to the top of the forum.";
$l['thread_review'] = "Thread Review (Newest First)";
$l['thread_review_more'] = "This thread has more than {1} replies. <a href=\"{2}\">Read the whole thread.</a>";
$l['posted_by'] = "Posted by";
$l['draft_saved'] = "The new post has successfully been saved as a draft.<br />You will now be taken to your draft listing.";
$l['image_verification'] = "Image Verification";
$l['verification_note'] = "Please enter the text contained within the image into the text box below it. This process is used to prevent automated posts.";
$l['verification_subnote'] = "(case insensitive)";
$l['invalid_captcha'] = "The image verification code that you entered was incorrect. Please enter the code exactly how it appears in the image.";
$l['error_post_already_submitted'] = "You have already posted this reply to the specified thread. Please visit the thread to see your reply.";
$l['multiquote_external_one'] = "You have selected one post outside of this thread.";
$l['multiquote_external'] = "You have selected {1} posts outside of this thread.";
$l['multiquote_external_one_deselect'] = "deselect this post";
$l['multiquote_external_deselect'] = "deselect these posts";
$l['multiquote_external_one_quote'] = "Quote this post too";
$l['multiquote_external_quote'] = "Quote these posts too";

$l['redirect_newreply'] = "Thank you, your reply has been posted.";
$l['redirect_newreply_moderation'] = "The administrator has specified that all new posts require moderation. You will now be returned to the thread.";
$l['redirect_newreply_post'] = "<br />You will now be taken to your post.";
$l['redirect_newreplyerror'] = "Sorry, but your reply has been rejected for lack of content. <br />You will now be returned to the thread.";
$l['redirect_threadclosed'] = "You cannot post replies in this thread because it has been closed by a moderator.";
$l['error_post_noperms'] = "You don't have permission to edit this draft.";
?>
